local CustomDecoration = ...

_PrefixAsset = "CUSTOM_DECORATION_V2"
_CommonWindowPrefix = "CUSTOM_WINDOW_V2"
_CommonDoorPrefix = "CUSTOM_DOOR_V2"
_CommonChurchPrefix = "CUSTOM_CHURCH_V2"

-- Register all stone gate set building parts and their properties
CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", "DECORATION")
CustomDecoration:dofile("scripts/compDecoration.lua")
CustomDecoration:dofile("scripts/decoration.lua")
CustomDecoration:dofile("scripts/compLeadWire.lua")
CustomDecoration:dofile("scripts/leadWire.lua")

-- Apply building asset processor
CustomDecoration:registerAssetProcessor("models/core.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

CustomDecoration:registerAssetId("models/core.fbx/Prefab/decoration/CoreBuildingPart", _PrefixAsset .. "_CORE_BUILDING_PREFAB")

-- Register the Core part
CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. "_CORE_BUILDING_PART",
	Name = _PrefixAsset .. "_CORE_BUILDING_NAME",
	Description = _PrefixAsset .. "_CORE_BUILDING_DESC",
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _PrefixAsset .. "_CORE_BUILDING_PREFAB"
	},
        IsVisibleWhenBuilt = false
})

function configureMaterielSetList(_colorRoof, _colorWall, _isDefaultMaterial)
    function configureMaterial(_core, _colorMaterial)
        if _isDefaultMaterial then
            return  _CommonWindowPrefix .. "_" .. _core .. "_" .. _colorMaterial .. "_MATERIAL"
        else
            return  _CommonWindowPrefix .. "_DECORATION_" .. _colorMaterial .. "_MATERIAL"
        end
    end
    return {
                SetName = _PrefixAsset .. "_" .. _colorRoof .. "_" .. _colorWall,
                MaterialList = {
                    configureMaterial("STONE_WINDOW", _colorRoof),
                    configureMaterial("WOODEN_DOOR", _colorRoof),
                    configureMaterial("WOODEN_WINDOW", _colorRoof),
-- used only by Stone Gate Set                    configureMaterial("WOODEN_ENTRANCE", _colorRoof),

                    configureMaterial("STONE_DECORATION", _colorWall),
                    configureMaterial("STONE_BUTTRESS", _colorWall)
                }
    }
end

CustomDecoration:register({
    DataType = "BUILDING",
    Id = _PrefixAsset .. "_MONUMENT",
    Name = _PrefixAsset .. "_MONUMENT_NAME",
    Description = _PrefixAsset .. "_MONUMENT_DESC",
    BuildingType = "DECORATION",
    AssetCoreBuildingPart = _PrefixAsset .. "_CORE_BUILDING_PART",
    BuildingPartSetList = {
		{
			Name = _PrefixAsset .. "_LEAD_WIRE_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _PrefixAsset .. "_LEAD_WIRE_ROOT_PART"
                        }
                },
                {
			Name = _PrefixAsset .. "_STONE_MONUMENT_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _PrefixAsset .. "_SFENETRE_ROOT_PART",
		            _PrefixAsset .. "_LFENETRE_ROOT_PART",
		            _PrefixAsset .. "_PFENETRE_ROOT_PART",
		            _PrefixAsset .. "_STONE_ROUND_WINDOW_ROOT_PART",
		            _PrefixAsset .. "_ARROWSLIT_ROOT_PART",
		            _PrefixAsset .. "_BALCONY_ROOT_PART",
		            _PrefixAsset .. "_CHIMNEY_ROOT_PART",
		            _PrefixAsset .. "_CHIMNEY_B_ROOT_PART",
		            _PrefixAsset .. "_TURRET_ROOT_PART",
		            _PrefixAsset .. "_BUTTRESS_ROOT_PART",
		            _PrefixAsset .. "_DOOR_A_ROOT_PART",
		            _PrefixAsset .. "_DOOR_B_ROOT_PART"
                        }  
                },
                {
			Name = _PrefixAsset .. "_WOODEN_MONUMENT_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _PrefixAsset .. "_WOODEN_DOOR_1_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_DOOR_3_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_DOOR_4_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_18_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_3_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_7_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_8_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_9_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_POINTED_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_ROUND_WINDOW_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_AMERICAN_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_STAIRS_1_ROOT_PART",
		            _PrefixAsset .. "_LUCARNE_ROOT_PART",
		            _PrefixAsset .. "_LUCARNE_WHITE_ROOT_PART", -- whith white chalk wall
		            _PrefixAsset .. "_LARGE_LUCARNE_ROOT_PART",
		            _PrefixAsset .. "_LARGE_LUCARNE_WHITE_ROOT_PART"
                        }  
                },
                {
			Name = _PrefixAsset .. "_IRON_MONUMENT_PARTSETLIST_NAME",
	                BuildingPartList = {
                            _PrefixAsset .. "_FINIAL1_ROOT_PART",
		            _PrefixAsset .. "_FINIAL2_ROOT_PART",
		            _PrefixAsset .. "_FINIAL3_ROOT_PART"
                        }   
                },
                {
			Name = _PrefixAsset .. "_STAINED_GLASS_PARTSETLIST_NAME",
	                BuildingPartList = {
                            _PrefixAsset .. "_STAINED_GLASS_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_2_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_3_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_4_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_8_ROOT_PART",
		            _PrefixAsset .. "_SPLENDOR_2_ROOT_PART",
		            _PrefixAsset .. "_P_STAINED_GLASS_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_TALL_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_TALL_2_ROOT_PART"
                        }   
                }
    },
    MaterialSetList = {
            configureMaterielSetList("RED_ROOF", "MANOR2_WALL", true), -- default material list
            configureMaterielSetList("BLUE_ROOF", "MANOR2_WALL", false),
            configureMaterielSetList("BROWN_ROOF", "MANOR2_WALL", false),
            configureMaterielSetList("GREY_ROOF", "MANOR2_WALL", false),
            configureMaterielSetList("GREY2_ROOF", "MANOR2_WALL", false),
            configureMaterielSetList("RED_WROOF", "MANOR2_WALL", false),
            configureMaterielSetList("BLUE_WROOF", "MANOR2_WALL", false),
            configureMaterielSetList("BROWN_WROOF", "MANOR2_WALL", false),
            configureMaterielSetList("YELLOW_WROOF", "MANOR2_WALL", false),
            configureMaterielSetList("GREEN_WROOF", "MANOR2_WALL", false),
            configureMaterielSetList("MANOR_WROOF", "MANOR2_WALL", false),
            configureMaterielSetList("MANOR2_WROOF", "MANOR2_WALL", false),
            configureMaterielSetList("BROWN_MONASTERY_ROOF", "BROWN_MONASTERY_WALL", false),
            configureMaterielSetList("BLUE_MONASTERY_ROOF", "BLUE_MONASTERY_WALL", false),
            configureMaterielSetList("PURPLE_MONASTERY_ROOF", "PURPLE_MONASTERY_WALL", false),
            configureMaterielSetList("MANOR_WROOF", "RED_STONE_WALL", false),
            configureMaterielSetList("RED_WROOF", "GIANT_GATE_WALL", false),
            configureMaterielSetList("STRAW_ROOF", "WHITE_CHALK_WALL", false),
            configureMaterielSetList("RED_ROOF", "SAND_STONE_WALL", false),
            configureMaterielSetList("BROWN_ROOF", "SAND_STONE_WALL", false),
            configureMaterielSetList("STRAW_ROOF", "WOOD_WALL", false),
    },
    IsEditable = true
})

-- Adds Stained glasses to the vanilla Church
CustomDecoration:override({
    Id = "MONUMENT_CHURCH",
    BuildingPartSetList = {
                Action = "APPEND",
		{
			Name = _CommonChurchPrefix .. "_ADDITION_NAME",
                	BuildingPartList = {
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_WINDOW_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_2_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_3_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_4_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_8_PART",
                            _CommonChurchPrefix .. "_DECORATION_SPLENDOR_2_PART",
                            _CommonChurchPrefix .. "_DECORATION_P_STAINED_GLASS_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_TALL_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_TALL_2_PART"
                        }
                }
    }
})

